#!/bin/bash

function help
{
  >&2 echo
  >&2 echo "Usage: $(basename ${0}) DB_NAME"
  >&2 echo
  >&2 echo "  DB_NAME - The full name of the DB as accessed in the code."
  >&2 echo "            E.g., RunKeeper.sqlite."
  >&2 echo
}

if [ ${#*} -lt 1 ]; then
  help
  exit 1
fi

DB_BASE_PATH=.

DB_SQL_BASE_PATH=.

DB_NAME=${1}
DB_NAME_GZIP=${DB_NAME}.gz
DB_PATH=${DB_BASE_PATH}/${DB_NAME}
DB_PATH_GZIP=${DB_BASE_PATH}/${DB_NAME_GZIP}
INITIAL_DB_SQL=${DB_SQL_BASE_PATH}/${DB_NAME}_initial_version.sql

function nextVerSql
{
  __NEXTVER=${1}
  __CURVER=$((__NEXTVER-1))
  __RETURN=${DB_SQL_BASE_PATH}/${DB_NAME}_upgrade_${__CURVER}-${__NEXTVER}.sql
}

function error
{
  >&2 echo "ERROR: ${1}"
  exit 1
}

function applySql
{
  __SQL=${1}
  __DB=${2}
  echo "Applying SQL patch, ${__SQL}, to DB, ${__DB}."
  ( cat ${__SQL} | sqlite3 ${__DB} ) || error "Unable to apply patch, ${__SQL}"
}

if [ -f ${DB_PATH} ]; then
  echo "Removing existing empty DB, ${DB_PATH}."
  rm -rf ${DB_PATH} || error "Unable to remove existing empty DB, ${DB_PATH}."
fi

if [ -f ${DB_PATH_GZIP} ]; then
  echo "Removing existing compressed empty DB, ${DB_PATH_GZIP}."
  rm -rf ${DB_PATH_GZIP} || error "Unable to remove existing compressed empty DB, ${DB_PATH_GZIP}."
fi

applySql ${INITIAL_DB_SQL} ${DB_PATH}

NEXT_VER=2
nextVerSql ${NEXT_VER}
UPDATE_FILE=${__RETURN}
while [ -f ${UPDATE_FILE} ]; do
  applySql ${UPDATE_FILE} ${DB_PATH}
  NEXT_VER=$((NEXT_VER+1))
  nextVerSql ${NEXT_VER}
  UPDATE_FILE=${__RETURN}
done

gzip ${DB_PATH} || error "Unable to compress created empty DB, ${DB_PATH}."
